# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/atlas.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2
from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.atlas import permission_pb2 as eolymp_dot_atlas_dot_permission__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import test_pb2 as eolymp_dot_atlas_dot_test__pb2
from eolymp.atlas import testset_pb2 as eolymp_dot_atlas_dot_testset__pb2
from eolymp.atlas import template_pb2 as eolymp_dot_atlas_dot_template__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/atlas.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65olymp/atlas/atlas.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/executor/verifier.proto\x1a eolymp/executor/interactor.proto\x1a\x1d\x65olymp/atlas/permission.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x17\x65olymp/atlas/test.proto\x1a\x1a\x65olymp/atlas/testset.proto\x1a\x1b\x65olymp/atlas/template.proto\"1\n\x11ListProblemsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Problem\"<\n\x12\x43reateProblemInput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\")\n\x13\x43reateProblemOutput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"*\n\x14\x44\x65scribeProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\")\n\x13ListStatementsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"M\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Statement\".\n\x16\x44\x65scribeStatementInput\x12\x14\n\x0cstatement_id\x18\x01 \x01(\t\"E\n\x17\x44\x65scribeStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"V\n\x14\x43reateStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"#\n\x15\x43reateStatementOutput\x12\n\n\x02id\x18\x01 \x01(\t\"X\n\x14UpdateStatementInput\x12\x14\n\x0cstatement_id\x18\x01 \x01(\t\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"\x17\n\x15UpdateStatementOutput\",\n\x14\x44\x65leteStatementInput\x12\x14\n\x0cstatement_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteStatementOutput\"V\n\x13UpdateVerifierInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12+\n\x08verifier\x18\x02 \x01(\x0b\x32\x19.eolymp.executor.Verifier\"\x16\n\x14UpdateVerifierOutput\"+\n\x15\x44\x65scribeVerifierInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeVerifierOutput\x12+\n\x08verifier\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Verifier\"\\\n\x15UpdateInteractorInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12/\n\ninteractor\x18\x02 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\"\x18\n\x16UpdateInteractorOutput\"-\n\x17\x44\x65scribeInteractorInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"K\n\x18\x44\x65scribeInteractorOutput\x12/\n\ninteractor\x18\x01 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\"\'\n\x11ListTestsetsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"I\n\x12ListTestsetsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Testset\"*\n\x14\x44\x65scribeTestsetInput\x12\x12\n\ntestset_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeTestsetOutput\x12&\n\x07testset\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"P\n\x12\x43reateTestsetInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12&\n\x07testset\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"!\n\x13\x43reateTestsetOutput\x12\n\n\x02id\x18\x01 \x01(\t\"P\n\x12UpdateTestsetInput\x12\x12\n\ntestset_id\x18\x01 \x01(\t\x12&\n\x07testset\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"\x15\n\x13UpdateTestsetOutput\"(\n\x12\x44\x65leteTestsetInput\x12\x12\n\ntestset_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteTestsetOutput\"\'\n\x11ListExamplesInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"$\n\x0eListTestsInput\x12\x12\n\ntestset_id\x18\x01 \x01(\t\"C\n\x0fListTestsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"$\n\x11\x44\x65scribeTestInput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"6\n\x12\x44\x65scribeTestOutput\x12 \n\x04test\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\"G\n\x0f\x43reateTestInput\x12\x12\n\ntestset_id\x18\x01 \x01(\t\x12 \n\x04test\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\"\x1e\n\x10\x43reateTestOutput\x12\n\n\x02id\x18\x01 \x01(\t\"D\n\x0fUpdateTestInput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\x12 \n\x04test\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\"\x12\n\x10UpdateTestOutput\"\"\n\x0f\x44\x65leteTestInput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65leteTestOutput\"*\n\x14ListPermissionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"@\n\x15ListPermissionsOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Permission\"X\n\x14GrantPermissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12,\n\npermission\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Permission\"\x17\n\x15GrantPermissionOutput\"<\n\x15RevokePermissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"\x18\n\x16RevokePermissionOutput\"W\n\x17\x43reateCodeTemplateInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x08template\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\"/\n\x18\x43reateCodeTemplateOutput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"X\n\x17UpdateCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\x12(\n\x08template\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\"\x1a\n\x18UpdateCodeTemplateOutput\".\n\x17\x44\x65leteCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteCodeTemplateOutput\",\n\x16ListCodeTemplatesInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"O\n\x17ListCodeTemplatesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Template\"0\n\x19\x44\x65scribeCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template2\xb4-\n\x05\x41tlas\x12\xa1\x01\n\rCreateProblem\x12 .eolymp.atlas.CreateProblemInput\x1a!.eolymp.atlas.CreateProblemOutput\"K\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1b\"\x10/atlas/problems/:\x07problem\x12\xa4\x01\n\rDeleteProblem\x12 .eolymp.atlas.DeleteProblemInput\x1a!.eolymp.atlas.DeleteProblemOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/atlas/problems/{problem_id}\x12\x94\x01\n\x0cListProblems\x12\x1f.eolymp.atlas.ListProblemsInput\x1a .eolymp.atlas.ListProblemsOutput\"A\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/atlas/problems/\x12\xb2\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.atlas.DescribeProblemInput\x1a#.eolymp.atlas.DescribeProblemOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\'\x12\x1c/atlas/problems/{problem_id}b\x07problem\x12\xaa\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\"W\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02(\x12&/atlas/problems/{problem_id}/examples/\x12\xba\x01\n\x0eUpdateVerifier\x12!.eolymp.atlas.UpdateVerifierInput\x1a\".eolymp.atlas.UpdateVerifierOutput\"a\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x31\x1a%/atlas/problems/{problem_id}/verifier:\x08verifier\x12\xc0\x01\n\x10\x44\x65scribeVerifier\x12#.eolymp.atlas.DescribeVerifierInput\x1a$.eolymp.atlas.DescribeVerifierOutput\"a\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x31\x12%/atlas/problems/{problem_id}/verifierb\x08verifier\x12\xc4\x01\n\x10UpdateInteractor\x12#.eolymp.atlas.UpdateInteractorInput\x1a$.eolymp.atlas.UpdateInteractorOutput\"e\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x35\x1a\'/atlas/problems/{problem_id}/interactor:\ninteractor\x12\xca\x01\n\x12\x44\x65scribeInteractor\x12%.eolymp.atlas.DescribeInteractorInput\x1a&.eolymp.atlas.DescribeInteractorOutput\"e\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x35\x12\'/atlas/problems/{problem_id}/interactorb\ninteractor\x12\xc1\x01\n\x0f\x43reateStatement\x12\".eolymp.atlas.CreateStatementInput\x1a#.eolymp.atlas.CreateStatementOutput\"e\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x35\x1a(/atlas/problems/{problem_id}/statements/:\tstatement\x12\xb9\x01\n\x0fUpdateStatement\x12\".eolymp.atlas.UpdateStatementInput\x1a#.eolymp.atlas.UpdateStatementOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\x1a /atlas/statements/{statement_id}:\tstatement\x12\xae\x01\n\x0f\x44\x65leteStatement\x12\".eolymp.atlas.DeleteStatementInput\x1a#.eolymp.atlas.DeleteStatementOutput\"R\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\"* /atlas/statements/{statement_id}\x12\xb2\x01\n\x0eListStatements\x12!.eolymp.atlas.ListStatementsInput\x1a\".eolymp.atlas.ListStatementsOutput\"Y\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02*\x12(/atlas/problems/{problem_id}/statements/\x12\xbe\x01\n\x11\x44\x65scribeStatement\x12$.eolymp.atlas.DescribeStatementInput\x1a%.eolymp.atlas.DescribeStatementOutput\"\\\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02-\x12 /atlas/statements/{statement_id}b\tstatement\x12\xb7\x01\n\rCreateTestset\x12 .eolymp.atlas.CreateTestsetInput\x1a!.eolymp.atlas.CreateTestsetOutput\"a\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x31\"&/atlas/problems/{problem_id}/testsets/:\x07testset\x12\xad\x01\n\rUpdateTestset\x12 .eolymp.atlas.UpdateTestsetInput\x1a!.eolymp.atlas.UpdateTestsetOutput\"W\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\x1a\x1c/atlas/testsets/{testset_id}:\x07testset\x12\xa4\x01\n\rDeleteTestset\x12 .eolymp.atlas.DeleteTestsetInput\x1a!.eolymp.atlas.DeleteTestsetOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/atlas/testsets/{testset_id}\x12\xab\x01\n\x0cListTestsets\x12\x1f.eolymp.atlas.ListTestsetsInput\x1a .eolymp.atlas.ListTestsetsOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02(\x12&/atlas/problems/{problem_id}/testsets/\x12\xb3\x01\n\x0f\x44\x65scribeTestset\x12\".eolymp.atlas.DescribeTestsetInput\x1a#.eolymp.atlas.DescribeTestsetOutput\"W\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\'\x12\x1c/atlas/testsets/{testset_id}b\x07testset\x12\xa7\x01\n\nCreateTest\x12\x1d.eolymp.atlas.CreateTestInput\x1a\x1e.eolymp.atlas.CreateTestOutput\"Z\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02*\"\"/atlas/testsets/{testset_id}/tests:\x04test\x12\x9b\x01\n\nUpdateTest\x12\x1d.eolymp.atlas.UpdateTestInput\x1a\x1e.eolymp.atlas.UpdateTestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x16/atlas/tests/{test_id}:\x04test\x12\x95\x01\n\nDeleteTest\x12\x1d.eolymp.atlas.DeleteTestInput\x1a\x1e.eolymp.atlas.DeleteTestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18*\x16/atlas/tests/{test_id}\x12\x9e\x01\n\tListTests\x12\x1c.eolymp.atlas.ListTestsInput\x1a\x1d.eolymp.atlas.ListTestsOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$\x12\"/atlas/testsets/{testset_id}/tests\x12\xa1\x01\n\x0c\x44\x65scribeTest\x12\x1f.eolymp.atlas.DescribeTestInput\x1a .eolymp.atlas.DescribeTestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x12\x16/atlas/tests/{test_id}b\x04test\x12\xc5\x01\n\x0fGrantPermission\x12\".eolymp.atlas.GrantPermissionInput\x1a#.eolymp.atlas.GrantPermissionOutput\"i\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:permission:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x36\"(/atlas/problems/{problem_id}/permissions:\npermission\x12\xc6\x01\n\x10RevokePermission\x12#.eolymp.atlas.RevokePermissionInput\x1a$.eolymp.atlas.RevokePermissionOutput\"g\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:permission:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x34*2/atlas/problems/{problem_id}/permissions/{user_id}\x12\xb8\x01\n\x0fListPermissions\x12\".eolymp.atlas.ListPermissionsInput\x1a#.eolymp.atlas.ListPermissionsOutput\"\\\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:permission:read\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02*\x12(/atlas/problems/{problem_id}/permissions\x12\xc7\x01\n\x12\x43reateCodeTemplate\x12%.eolymp.atlas.CreateCodeTemplateInput\x1a&.eolymp.atlas.CreateCodeTemplateOutput\"b\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32\"&/atlas/problems/{problem_id}/templates:\x08template\x12\xbf\x01\n\x12UpdateCodeTemplate\x12%.eolymp.atlas.UpdateCodeTemplateInput\x1a&.eolymp.atlas.UpdateCodeTemplateOutput\"Z\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02*\"\x1e/atlas/templates/{template_id}:\x08template\x12\xb5\x01\n\x12\x44\x65leteCodeTemplate\x12%.eolymp.atlas.DeleteCodeTemplateInput\x1a&.eolymp.atlas.DeleteCodeTemplateOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 *\x1e/atlas/templates/{template_id}\x12\xba\x01\n\x11ListCodeTemplates\x12$.eolymp.atlas.ListCodeTemplatesInput\x1a%.eolymp.atlas.ListCodeTemplatesOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02)\x12\'/atlas/problems/{problems_id}/templates\x12\xc4\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.atlas.DescribeCodeTemplateInput\x1a(.eolymp.atlas.DescribeCodeTemplateOutput\"Y\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02*\x12\x1e/atlas/templates/{template_id}b\x08templateB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_executor_dot_verifier__pb2.DESCRIPTOR,eolymp_dot_executor_dot_interactor__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_permission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_problem__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_statement__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_test__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_testset__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_template__pb2.DESCRIPTOR,])




_LISTPROBLEMSINPUT = _descriptor.Descriptor(
  name='ListProblemsInput',
  full_name='eolymp.atlas.ListProblemsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.atlas.ListProblemsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.atlas.ListProblemsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=427,
)


_LISTPROBLEMSOUTPUT = _descriptor.Descriptor(
  name='ListProblemsOutput',
  full_name='eolymp.atlas.ListProblemsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.atlas.ListProblemsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.atlas.ListProblemsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=502,
)


_CREATEPROBLEMINPUT = _descriptor.Descriptor(
  name='CreateProblemInput',
  full_name='eolymp.atlas.CreateProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.CreateProblemInput.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=564,
)


_CREATEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='CreateProblemOutput',
  full_name='eolymp.atlas.CreateProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.CreateProblemOutput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=607,
)


_DELETEPROBLEMINPUT = _descriptor.Descriptor(
  name='DeleteProblemInput',
  full_name='eolymp.atlas.DeleteProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DeleteProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=649,
)


_DELETEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DeleteProblemOutput',
  full_name='eolymp.atlas.DeleteProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=672,
)


_DESCRIBEPROBLEMINPUT = _descriptor.Descriptor(
  name='DescribeProblemInput',
  full_name='eolymp.atlas.DescribeProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DescribeProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=716,
)


_DESCRIBEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DescribeProblemOutput',
  full_name='eolymp.atlas.DescribeProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.DescribeProblemOutput.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=781,
)


_LISTSTATEMENTSINPUT = _descriptor.Descriptor(
  name='ListStatementsInput',
  full_name='eolymp.atlas.ListStatementsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ListStatementsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=824,
)


_LISTSTATEMENTSOUTPUT = _descriptor.Descriptor(
  name='ListStatementsOutput',
  full_name='eolymp.atlas.ListStatementsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.atlas.ListStatementsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.atlas.ListStatementsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=903,
)


_DESCRIBESTATEMENTINPUT = _descriptor.Descriptor(
  name='DescribeStatementInput',
  full_name='eolymp.atlas.DescribeStatementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statement_id', full_name='eolymp.atlas.DescribeStatementInput.statement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=951,
)


_DESCRIBESTATEMENTOUTPUT = _descriptor.Descriptor(
  name='DescribeStatementOutput',
  full_name='eolymp.atlas.DescribeStatementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statement', full_name='eolymp.atlas.DescribeStatementOutput.statement', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1022,
)


_CREATESTATEMENTINPUT = _descriptor.Descriptor(
  name='CreateStatementInput',
  full_name='eolymp.atlas.CreateStatementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.CreateStatementInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statement', full_name='eolymp.atlas.CreateStatementInput.statement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1110,
)


_CREATESTATEMENTOUTPUT = _descriptor.Descriptor(
  name='CreateStatementOutput',
  full_name='eolymp.atlas.CreateStatementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.CreateStatementOutput.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1147,
)


_UPDATESTATEMENTINPUT = _descriptor.Descriptor(
  name='UpdateStatementInput',
  full_name='eolymp.atlas.UpdateStatementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statement_id', full_name='eolymp.atlas.UpdateStatementInput.statement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statement', full_name='eolymp.atlas.UpdateStatementInput.statement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=1237,
)


_UPDATESTATEMENTOUTPUT = _descriptor.Descriptor(
  name='UpdateStatementOutput',
  full_name='eolymp.atlas.UpdateStatementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1262,
)


_DELETESTATEMENTINPUT = _descriptor.Descriptor(
  name='DeleteStatementInput',
  full_name='eolymp.atlas.DeleteStatementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statement_id', full_name='eolymp.atlas.DeleteStatementInput.statement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1264,
  serialized_end=1308,
)


_DELETESTATEMENTOUTPUT = _descriptor.Descriptor(
  name='DeleteStatementOutput',
  full_name='eolymp.atlas.DeleteStatementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1310,
  serialized_end=1333,
)


_UPDATEVERIFIERINPUT = _descriptor.Descriptor(
  name='UpdateVerifierInput',
  full_name='eolymp.atlas.UpdateVerifierInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateVerifierInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verifier', full_name='eolymp.atlas.UpdateVerifierInput.verifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1335,
  serialized_end=1421,
)


_UPDATEVERIFIEROUTPUT = _descriptor.Descriptor(
  name='UpdateVerifierOutput',
  full_name='eolymp.atlas.UpdateVerifierOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1445,
)


_DESCRIBEVERIFIERINPUT = _descriptor.Descriptor(
  name='DescribeVerifierInput',
  full_name='eolymp.atlas.DescribeVerifierInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DescribeVerifierInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1490,
)


_DESCRIBEVERIFIEROUTPUT = _descriptor.Descriptor(
  name='DescribeVerifierOutput',
  full_name='eolymp.atlas.DescribeVerifierOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='verifier', full_name='eolymp.atlas.DescribeVerifierOutput.verifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1492,
  serialized_end=1561,
)


_UPDATEINTERACTORINPUT = _descriptor.Descriptor(
  name='UpdateInteractorInput',
  full_name='eolymp.atlas.UpdateInteractorInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.UpdateInteractorInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactor', full_name='eolymp.atlas.UpdateInteractorInput.interactor', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1563,
  serialized_end=1655,
)


_UPDATEINTERACTOROUTPUT = _descriptor.Descriptor(
  name='UpdateInteractorOutput',
  full_name='eolymp.atlas.UpdateInteractorOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1657,
  serialized_end=1681,
)


_DESCRIBEINTERACTORINPUT = _descriptor.Descriptor(
  name='DescribeInteractorInput',
  full_name='eolymp.atlas.DescribeInteractorInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.DescribeInteractorInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1728,
)


_DESCRIBEINTERACTOROUTPUT = _descriptor.Descriptor(
  name='DescribeInteractorOutput',
  full_name='eolymp.atlas.DescribeInteractorOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interactor', full_name='eolymp.atlas.DescribeInteractorOutput.interactor', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1805,
)


_LISTTESTSETSINPUT = _descriptor.Descriptor(
  name='ListTestsetsInput',
  full_name='eolymp.atlas.ListTestsetsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ListTestsetsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1807,
  serialized_end=1846,
)


_LISTTESTSETSOUTPUT = _descriptor.Descriptor(
  name='ListTestsetsOutput',
  full_name='eolymp.atlas.ListTestsetsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.atlas.ListTestsetsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.atlas.ListTestsetsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1921,
)


_DESCRIBETESTSETINPUT = _descriptor.Descriptor(
  name='DescribeTestsetInput',
  full_name='eolymp.atlas.DescribeTestsetInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.atlas.DescribeTestsetInput.testset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=1965,
)


_DESCRIBETESTSETOUTPUT = _descriptor.Descriptor(
  name='DescribeTestsetOutput',
  full_name='eolymp.atlas.DescribeTestsetOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testset', full_name='eolymp.atlas.DescribeTestsetOutput.testset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1967,
  serialized_end=2030,
)


_CREATETESTSETINPUT = _descriptor.Descriptor(
  name='CreateTestsetInput',
  full_name='eolymp.atlas.CreateTestsetInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.CreateTestsetInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testset', full_name='eolymp.atlas.CreateTestsetInput.testset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2032,
  serialized_end=2112,
)


_CREATETESTSETOUTPUT = _descriptor.Descriptor(
  name='CreateTestsetOutput',
  full_name='eolymp.atlas.CreateTestsetOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.CreateTestsetOutput.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2114,
  serialized_end=2147,
)


_UPDATETESTSETINPUT = _descriptor.Descriptor(
  name='UpdateTestsetInput',
  full_name='eolymp.atlas.UpdateTestsetInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.atlas.UpdateTestsetInput.testset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testset', full_name='eolymp.atlas.UpdateTestsetInput.testset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2149,
  serialized_end=2229,
)


_UPDATETESTSETOUTPUT = _descriptor.Descriptor(
  name='UpdateTestsetOutput',
  full_name='eolymp.atlas.UpdateTestsetOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2231,
  serialized_end=2252,
)


_DELETETESTSETINPUT = _descriptor.Descriptor(
  name='DeleteTestsetInput',
  full_name='eolymp.atlas.DeleteTestsetInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.atlas.DeleteTestsetInput.testset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2254,
  serialized_end=2294,
)


_DELETETESTSETOUTPUT = _descriptor.Descriptor(
  name='DeleteTestsetOutput',
  full_name='eolymp.atlas.DeleteTestsetOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2296,
  serialized_end=2317,
)


_LISTEXAMPLESINPUT = _descriptor.Descriptor(
  name='ListExamplesInput',
  full_name='eolymp.atlas.ListExamplesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ListExamplesInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2319,
  serialized_end=2358,
)


_LISTEXAMPLESOUTPUT = _descriptor.Descriptor(
  name='ListExamplesOutput',
  full_name='eolymp.atlas.ListExamplesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='examples', full_name='eolymp.atlas.ListExamplesOutput.examples', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2360,
  serialized_end=2418,
)


_LISTTESTSINPUT = _descriptor.Descriptor(
  name='ListTestsInput',
  full_name='eolymp.atlas.ListTestsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.atlas.ListTestsInput.testset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2420,
  serialized_end=2456,
)


_LISTTESTSOUTPUT = _descriptor.Descriptor(
  name='ListTestsOutput',
  full_name='eolymp.atlas.ListTestsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.atlas.ListTestsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.atlas.ListTestsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2458,
  serialized_end=2525,
)


_DESCRIBETESTINPUT = _descriptor.Descriptor(
  name='DescribeTestInput',
  full_name='eolymp.atlas.DescribeTestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='eolymp.atlas.DescribeTestInput.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2527,
  serialized_end=2563,
)


_DESCRIBETESTOUTPUT = _descriptor.Descriptor(
  name='DescribeTestOutput',
  full_name='eolymp.atlas.DescribeTestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test', full_name='eolymp.atlas.DescribeTestOutput.test', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2565,
  serialized_end=2619,
)


_CREATETESTINPUT = _descriptor.Descriptor(
  name='CreateTestInput',
  full_name='eolymp.atlas.CreateTestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testset_id', full_name='eolymp.atlas.CreateTestInput.testset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test', full_name='eolymp.atlas.CreateTestInput.test', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2621,
  serialized_end=2692,
)


_CREATETESTOUTPUT = _descriptor.Descriptor(
  name='CreateTestOutput',
  full_name='eolymp.atlas.CreateTestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.CreateTestOutput.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2694,
  serialized_end=2724,
)


_UPDATETESTINPUT = _descriptor.Descriptor(
  name='UpdateTestInput',
  full_name='eolymp.atlas.UpdateTestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='eolymp.atlas.UpdateTestInput.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test', full_name='eolymp.atlas.UpdateTestInput.test', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2794,
)


_UPDATETESTOUTPUT = _descriptor.Descriptor(
  name='UpdateTestOutput',
  full_name='eolymp.atlas.UpdateTestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2796,
  serialized_end=2814,
)


_DELETETESTINPUT = _descriptor.Descriptor(
  name='DeleteTestInput',
  full_name='eolymp.atlas.DeleteTestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='test_id', full_name='eolymp.atlas.DeleteTestInput.test_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2816,
  serialized_end=2850,
)


_DELETETESTOUTPUT = _descriptor.Descriptor(
  name='DeleteTestOutput',
  full_name='eolymp.atlas.DeleteTestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2852,
  serialized_end=2870,
)


_LISTPERMISSIONSINPUT = _descriptor.Descriptor(
  name='ListPermissionsInput',
  full_name='eolymp.atlas.ListPermissionsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ListPermissionsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2872,
  serialized_end=2914,
)


_LISTPERMISSIONSOUTPUT = _descriptor.Descriptor(
  name='ListPermissionsOutput',
  full_name='eolymp.atlas.ListPermissionsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.atlas.ListPermissionsOutput.items', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2916,
  serialized_end=2980,
)


_GRANTPERMISSIONINPUT = _descriptor.Descriptor(
  name='GrantPermissionInput',
  full_name='eolymp.atlas.GrantPermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.GrantPermissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='eolymp.atlas.GrantPermissionInput.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2982,
  serialized_end=3070,
)


_GRANTPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='GrantPermissionOutput',
  full_name='eolymp.atlas.GrantPermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3072,
  serialized_end=3095,
)


_REVOKEPERMISSIONINPUT = _descriptor.Descriptor(
  name='RevokePermissionInput',
  full_name='eolymp.atlas.RevokePermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.RevokePermissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.atlas.RevokePermissionInput.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3097,
  serialized_end=3157,
)


_REVOKEPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='RevokePermissionOutput',
  full_name='eolymp.atlas.RevokePermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3159,
  serialized_end=3183,
)


_CREATECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='CreateCodeTemplateInput',
  full_name='eolymp.atlas.CreateCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.CreateCodeTemplateInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.atlas.CreateCodeTemplateInput.template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3185,
  serialized_end=3272,
)


_CREATECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='CreateCodeTemplateOutput',
  full_name='eolymp.atlas.CreateCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='eolymp.atlas.CreateCodeTemplateOutput.template_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3274,
  serialized_end=3321,
)


_UPDATECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='UpdateCodeTemplateInput',
  full_name='eolymp.atlas.UpdateCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='eolymp.atlas.UpdateCodeTemplateInput.template_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.atlas.UpdateCodeTemplateInput.template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3323,
  serialized_end=3411,
)


_UPDATECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='UpdateCodeTemplateOutput',
  full_name='eolymp.atlas.UpdateCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3413,
  serialized_end=3439,
)


_DELETECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='DeleteCodeTemplateInput',
  full_name='eolymp.atlas.DeleteCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='eolymp.atlas.DeleteCodeTemplateInput.template_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3441,
  serialized_end=3487,
)


_DELETECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='DeleteCodeTemplateOutput',
  full_name='eolymp.atlas.DeleteCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3489,
  serialized_end=3515,
)


_LISTCODETEMPLATESINPUT = _descriptor.Descriptor(
  name='ListCodeTemplatesInput',
  full_name='eolymp.atlas.ListCodeTemplatesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ListCodeTemplatesInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3517,
  serialized_end=3561,
)


_LISTCODETEMPLATESOUTPUT = _descriptor.Descriptor(
  name='ListCodeTemplatesOutput',
  full_name='eolymp.atlas.ListCodeTemplatesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.atlas.ListCodeTemplatesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.atlas.ListCodeTemplatesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3563,
  serialized_end=3642,
)


_DESCRIBECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateInput',
  full_name='eolymp.atlas.DescribeCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_id', full_name='eolymp.atlas.DescribeCodeTemplateInput.template_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3644,
  serialized_end=3692,
)


_DESCRIBECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateOutput',
  full_name='eolymp.atlas.DescribeCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.atlas.DescribeCodeTemplateOutput.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3694,
  serialized_end=3764,
)

_LISTPROBLEMSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_CREATEPROBLEMINPUT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_DESCRIBEPROBLEMOUTPUT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_LISTSTATEMENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_DESCRIBESTATEMENTOUTPUT.fields_by_name['statement'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_CREATESTATEMENTINPUT.fields_by_name['statement'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_UPDATESTATEMENTINPUT.fields_by_name['statement'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_UPDATEVERIFIERINPUT.fields_by_name['verifier'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_DESCRIBEVERIFIEROUTPUT.fields_by_name['verifier'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_UPDATEINTERACTORINPUT.fields_by_name['interactor'].message_type = eolymp_dot_executor_dot_interactor__pb2._INTERACTOR
_DESCRIBEINTERACTOROUTPUT.fields_by_name['interactor'].message_type = eolymp_dot_executor_dot_interactor__pb2._INTERACTOR
_LISTTESTSETSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_DESCRIBETESTSETOUTPUT.fields_by_name['testset'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_CREATETESTSETINPUT.fields_by_name['testset'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_UPDATETESTSETINPUT.fields_by_name['testset'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_LISTEXAMPLESOUTPUT.fields_by_name['examples'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_LISTTESTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_DESCRIBETESTOUTPUT.fields_by_name['test'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_CREATETESTINPUT.fields_by_name['test'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_UPDATETESTINPUT.fields_by_name['test'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_LISTPERMISSIONSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_GRANTPERMISSIONINPUT.fields_by_name['permission'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_CREATECODETEMPLATEINPUT.fields_by_name['template'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_UPDATECODETEMPLATEINPUT.fields_by_name['template'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_LISTCODETEMPLATESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_DESCRIBECODETEMPLATEOUTPUT.fields_by_name['template'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
DESCRIPTOR.message_types_by_name['ListProblemsInput'] = _LISTPROBLEMSINPUT
DESCRIPTOR.message_types_by_name['ListProblemsOutput'] = _LISTPROBLEMSOUTPUT
DESCRIPTOR.message_types_by_name['CreateProblemInput'] = _CREATEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['CreateProblemOutput'] = _CREATEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['DeleteProblemInput'] = _DELETEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DeleteProblemOutput'] = _DELETEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['DescribeProblemInput'] = _DESCRIBEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DescribeProblemOutput'] = _DESCRIBEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['ListStatementsInput'] = _LISTSTATEMENTSINPUT
DESCRIPTOR.message_types_by_name['ListStatementsOutput'] = _LISTSTATEMENTSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeStatementInput'] = _DESCRIBESTATEMENTINPUT
DESCRIPTOR.message_types_by_name['DescribeStatementOutput'] = _DESCRIBESTATEMENTOUTPUT
DESCRIPTOR.message_types_by_name['CreateStatementInput'] = _CREATESTATEMENTINPUT
DESCRIPTOR.message_types_by_name['CreateStatementOutput'] = _CREATESTATEMENTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateStatementInput'] = _UPDATESTATEMENTINPUT
DESCRIPTOR.message_types_by_name['UpdateStatementOutput'] = _UPDATESTATEMENTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteStatementInput'] = _DELETESTATEMENTINPUT
DESCRIPTOR.message_types_by_name['DeleteStatementOutput'] = _DELETESTATEMENTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateVerifierInput'] = _UPDATEVERIFIERINPUT
DESCRIPTOR.message_types_by_name['UpdateVerifierOutput'] = _UPDATEVERIFIEROUTPUT
DESCRIPTOR.message_types_by_name['DescribeVerifierInput'] = _DESCRIBEVERIFIERINPUT
DESCRIPTOR.message_types_by_name['DescribeVerifierOutput'] = _DESCRIBEVERIFIEROUTPUT
DESCRIPTOR.message_types_by_name['UpdateInteractorInput'] = _UPDATEINTERACTORINPUT
DESCRIPTOR.message_types_by_name['UpdateInteractorOutput'] = _UPDATEINTERACTOROUTPUT
DESCRIPTOR.message_types_by_name['DescribeInteractorInput'] = _DESCRIBEINTERACTORINPUT
DESCRIPTOR.message_types_by_name['DescribeInteractorOutput'] = _DESCRIBEINTERACTOROUTPUT
DESCRIPTOR.message_types_by_name['ListTestsetsInput'] = _LISTTESTSETSINPUT
DESCRIPTOR.message_types_by_name['ListTestsetsOutput'] = _LISTTESTSETSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeTestsetInput'] = _DESCRIBETESTSETINPUT
DESCRIPTOR.message_types_by_name['DescribeTestsetOutput'] = _DESCRIBETESTSETOUTPUT
DESCRIPTOR.message_types_by_name['CreateTestsetInput'] = _CREATETESTSETINPUT
DESCRIPTOR.message_types_by_name['CreateTestsetOutput'] = _CREATETESTSETOUTPUT
DESCRIPTOR.message_types_by_name['UpdateTestsetInput'] = _UPDATETESTSETINPUT
DESCRIPTOR.message_types_by_name['UpdateTestsetOutput'] = _UPDATETESTSETOUTPUT
DESCRIPTOR.message_types_by_name['DeleteTestsetInput'] = _DELETETESTSETINPUT
DESCRIPTOR.message_types_by_name['DeleteTestsetOutput'] = _DELETETESTSETOUTPUT
DESCRIPTOR.message_types_by_name['ListExamplesInput'] = _LISTEXAMPLESINPUT
DESCRIPTOR.message_types_by_name['ListExamplesOutput'] = _LISTEXAMPLESOUTPUT
DESCRIPTOR.message_types_by_name['ListTestsInput'] = _LISTTESTSINPUT
DESCRIPTOR.message_types_by_name['ListTestsOutput'] = _LISTTESTSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeTestInput'] = _DESCRIBETESTINPUT
DESCRIPTOR.message_types_by_name['DescribeTestOutput'] = _DESCRIBETESTOUTPUT
DESCRIPTOR.message_types_by_name['CreateTestInput'] = _CREATETESTINPUT
DESCRIPTOR.message_types_by_name['CreateTestOutput'] = _CREATETESTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateTestInput'] = _UPDATETESTINPUT
DESCRIPTOR.message_types_by_name['UpdateTestOutput'] = _UPDATETESTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteTestInput'] = _DELETETESTINPUT
DESCRIPTOR.message_types_by_name['DeleteTestOutput'] = _DELETETESTOUTPUT
DESCRIPTOR.message_types_by_name['ListPermissionsInput'] = _LISTPERMISSIONSINPUT
DESCRIPTOR.message_types_by_name['ListPermissionsOutput'] = _LISTPERMISSIONSOUTPUT
DESCRIPTOR.message_types_by_name['GrantPermissionInput'] = _GRANTPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['GrantPermissionOutput'] = _GRANTPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['RevokePermissionInput'] = _REVOKEPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['RevokePermissionOutput'] = _REVOKEPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['CreateCodeTemplateInput'] = _CREATECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['CreateCodeTemplateOutput'] = _CREATECODETEMPLATEOUTPUT
DESCRIPTOR.message_types_by_name['UpdateCodeTemplateInput'] = _UPDATECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['UpdateCodeTemplateOutput'] = _UPDATECODETEMPLATEOUTPUT
DESCRIPTOR.message_types_by_name['DeleteCodeTemplateInput'] = _DELETECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['DeleteCodeTemplateOutput'] = _DELETECODETEMPLATEOUTPUT
DESCRIPTOR.message_types_by_name['ListCodeTemplatesInput'] = _LISTCODETEMPLATESINPUT
DESCRIPTOR.message_types_by_name['ListCodeTemplatesOutput'] = _LISTCODETEMPLATESOUTPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateInput'] = _DESCRIBECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateOutput'] = _DESCRIBECODETEMPLATEOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListProblemsInput = _reflection.GeneratedProtocolMessageType('ListProblemsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROBLEMSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListProblemsInput)
  })
_sym_db.RegisterMessage(ListProblemsInput)

ListProblemsOutput = _reflection.GeneratedProtocolMessageType('ListProblemsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROBLEMSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListProblemsOutput)
  })
_sym_db.RegisterMessage(ListProblemsOutput)

CreateProblemInput = _reflection.GeneratedProtocolMessageType('CreateProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateProblemInput)
  })
_sym_db.RegisterMessage(CreateProblemInput)

CreateProblemOutput = _reflection.GeneratedProtocolMessageType('CreateProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateProblemOutput)
  })
_sym_db.RegisterMessage(CreateProblemOutput)

DeleteProblemInput = _reflection.GeneratedProtocolMessageType('DeleteProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteProblemInput)
  })
_sym_db.RegisterMessage(DeleteProblemInput)

DeleteProblemOutput = _reflection.GeneratedProtocolMessageType('DeleteProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteProblemOutput)
  })
_sym_db.RegisterMessage(DeleteProblemOutput)

DescribeProblemInput = _reflection.GeneratedProtocolMessageType('DescribeProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeProblemInput)
  })
_sym_db.RegisterMessage(DescribeProblemInput)

DescribeProblemOutput = _reflection.GeneratedProtocolMessageType('DescribeProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeProblemOutput)
  })
_sym_db.RegisterMessage(DescribeProblemOutput)

ListStatementsInput = _reflection.GeneratedProtocolMessageType('ListStatementsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTATEMENTSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListStatementsInput)
  })
_sym_db.RegisterMessage(ListStatementsInput)

ListStatementsOutput = _reflection.GeneratedProtocolMessageType('ListStatementsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTATEMENTSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListStatementsOutput)
  })
_sym_db.RegisterMessage(ListStatementsOutput)

DescribeStatementInput = _reflection.GeneratedProtocolMessageType('DescribeStatementInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESTATEMENTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeStatementInput)
  })
_sym_db.RegisterMessage(DescribeStatementInput)

DescribeStatementOutput = _reflection.GeneratedProtocolMessageType('DescribeStatementOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESTATEMENTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeStatementOutput)
  })
_sym_db.RegisterMessage(DescribeStatementOutput)

CreateStatementInput = _reflection.GeneratedProtocolMessageType('CreateStatementInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTATEMENTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateStatementInput)
  })
_sym_db.RegisterMessage(CreateStatementInput)

CreateStatementOutput = _reflection.GeneratedProtocolMessageType('CreateStatementOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTATEMENTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateStatementOutput)
  })
_sym_db.RegisterMessage(CreateStatementOutput)

UpdateStatementInput = _reflection.GeneratedProtocolMessageType('UpdateStatementInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTATEMENTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateStatementInput)
  })
_sym_db.RegisterMessage(UpdateStatementInput)

UpdateStatementOutput = _reflection.GeneratedProtocolMessageType('UpdateStatementOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTATEMENTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateStatementOutput)
  })
_sym_db.RegisterMessage(UpdateStatementOutput)

DeleteStatementInput = _reflection.GeneratedProtocolMessageType('DeleteStatementInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEMENTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteStatementInput)
  })
_sym_db.RegisterMessage(DeleteStatementInput)

DeleteStatementOutput = _reflection.GeneratedProtocolMessageType('DeleteStatementOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEMENTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteStatementOutput)
  })
_sym_db.RegisterMessage(DeleteStatementOutput)

UpdateVerifierInput = _reflection.GeneratedProtocolMessageType('UpdateVerifierInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVERIFIERINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateVerifierInput)
  })
_sym_db.RegisterMessage(UpdateVerifierInput)

UpdateVerifierOutput = _reflection.GeneratedProtocolMessageType('UpdateVerifierOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVERIFIEROUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateVerifierOutput)
  })
_sym_db.RegisterMessage(UpdateVerifierOutput)

DescribeVerifierInput = _reflection.GeneratedProtocolMessageType('DescribeVerifierInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVERIFIERINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeVerifierInput)
  })
_sym_db.RegisterMessage(DescribeVerifierInput)

DescribeVerifierOutput = _reflection.GeneratedProtocolMessageType('DescribeVerifierOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVERIFIEROUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeVerifierOutput)
  })
_sym_db.RegisterMessage(DescribeVerifierOutput)

UpdateInteractorInput = _reflection.GeneratedProtocolMessageType('UpdateInteractorInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINTERACTORINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateInteractorInput)
  })
_sym_db.RegisterMessage(UpdateInteractorInput)

UpdateInteractorOutput = _reflection.GeneratedProtocolMessageType('UpdateInteractorOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINTERACTOROUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateInteractorOutput)
  })
_sym_db.RegisterMessage(UpdateInteractorOutput)

DescribeInteractorInput = _reflection.GeneratedProtocolMessageType('DescribeInteractorInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINTERACTORINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeInteractorInput)
  })
_sym_db.RegisterMessage(DescribeInteractorInput)

DescribeInteractorOutput = _reflection.GeneratedProtocolMessageType('DescribeInteractorOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINTERACTOROUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeInteractorOutput)
  })
_sym_db.RegisterMessage(DescribeInteractorOutput)

ListTestsetsInput = _reflection.GeneratedProtocolMessageType('ListTestsetsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTTESTSETSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListTestsetsInput)
  })
_sym_db.RegisterMessage(ListTestsetsInput)

ListTestsetsOutput = _reflection.GeneratedProtocolMessageType('ListTestsetsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTTESTSETSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListTestsetsOutput)
  })
_sym_db.RegisterMessage(ListTestsetsOutput)

DescribeTestsetInput = _reflection.GeneratedProtocolMessageType('DescribeTestsetInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETESTSETINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeTestsetInput)
  })
_sym_db.RegisterMessage(DescribeTestsetInput)

DescribeTestsetOutput = _reflection.GeneratedProtocolMessageType('DescribeTestsetOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETESTSETOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeTestsetOutput)
  })
_sym_db.RegisterMessage(DescribeTestsetOutput)

CreateTestsetInput = _reflection.GeneratedProtocolMessageType('CreateTestsetInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETESTSETINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateTestsetInput)
  })
_sym_db.RegisterMessage(CreateTestsetInput)

CreateTestsetOutput = _reflection.GeneratedProtocolMessageType('CreateTestsetOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETESTSETOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateTestsetOutput)
  })
_sym_db.RegisterMessage(CreateTestsetOutput)

UpdateTestsetInput = _reflection.GeneratedProtocolMessageType('UpdateTestsetInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTSETINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateTestsetInput)
  })
_sym_db.RegisterMessage(UpdateTestsetInput)

UpdateTestsetOutput = _reflection.GeneratedProtocolMessageType('UpdateTestsetOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTSETOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateTestsetOutput)
  })
_sym_db.RegisterMessage(UpdateTestsetOutput)

DeleteTestsetInput = _reflection.GeneratedProtocolMessageType('DeleteTestsetInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETESTSETINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteTestsetInput)
  })
_sym_db.RegisterMessage(DeleteTestsetInput)

DeleteTestsetOutput = _reflection.GeneratedProtocolMessageType('DeleteTestsetOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETESTSETOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteTestsetOutput)
  })
_sym_db.RegisterMessage(DeleteTestsetOutput)

ListExamplesInput = _reflection.GeneratedProtocolMessageType('ListExamplesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXAMPLESINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListExamplesInput)
  })
_sym_db.RegisterMessage(ListExamplesInput)

ListExamplesOutput = _reflection.GeneratedProtocolMessageType('ListExamplesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXAMPLESOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListExamplesOutput)
  })
_sym_db.RegisterMessage(ListExamplesOutput)

ListTestsInput = _reflection.GeneratedProtocolMessageType('ListTestsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTTESTSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListTestsInput)
  })
_sym_db.RegisterMessage(ListTestsInput)

ListTestsOutput = _reflection.GeneratedProtocolMessageType('ListTestsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTTESTSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListTestsOutput)
  })
_sym_db.RegisterMessage(ListTestsOutput)

DescribeTestInput = _reflection.GeneratedProtocolMessageType('DescribeTestInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETESTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeTestInput)
  })
_sym_db.RegisterMessage(DescribeTestInput)

DescribeTestOutput = _reflection.GeneratedProtocolMessageType('DescribeTestOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETESTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeTestOutput)
  })
_sym_db.RegisterMessage(DescribeTestOutput)

CreateTestInput = _reflection.GeneratedProtocolMessageType('CreateTestInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETESTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateTestInput)
  })
_sym_db.RegisterMessage(CreateTestInput)

CreateTestOutput = _reflection.GeneratedProtocolMessageType('CreateTestOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETESTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateTestOutput)
  })
_sym_db.RegisterMessage(CreateTestOutput)

UpdateTestInput = _reflection.GeneratedProtocolMessageType('UpdateTestInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateTestInput)
  })
_sym_db.RegisterMessage(UpdateTestInput)

UpdateTestOutput = _reflection.GeneratedProtocolMessageType('UpdateTestOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETESTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateTestOutput)
  })
_sym_db.RegisterMessage(UpdateTestOutput)

DeleteTestInput = _reflection.GeneratedProtocolMessageType('DeleteTestInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETESTINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteTestInput)
  })
_sym_db.RegisterMessage(DeleteTestInput)

DeleteTestOutput = _reflection.GeneratedProtocolMessageType('DeleteTestOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETESTOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteTestOutput)
  })
_sym_db.RegisterMessage(DeleteTestOutput)

ListPermissionsInput = _reflection.GeneratedProtocolMessageType('ListPermissionsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListPermissionsInput)
  })
_sym_db.RegisterMessage(ListPermissionsInput)

ListPermissionsOutput = _reflection.GeneratedProtocolMessageType('ListPermissionsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListPermissionsOutput)
  })
_sym_db.RegisterMessage(ListPermissionsOutput)

GrantPermissionInput = _reflection.GeneratedProtocolMessageType('GrantPermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPERMISSIONINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.GrantPermissionInput)
  })
_sym_db.RegisterMessage(GrantPermissionInput)

GrantPermissionOutput = _reflection.GeneratedProtocolMessageType('GrantPermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPERMISSIONOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.GrantPermissionOutput)
  })
_sym_db.RegisterMessage(GrantPermissionOutput)

RevokePermissionInput = _reflection.GeneratedProtocolMessageType('RevokePermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.RevokePermissionInput)
  })
_sym_db.RegisterMessage(RevokePermissionInput)

RevokePermissionOutput = _reflection.GeneratedProtocolMessageType('RevokePermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.RevokePermissionOutput)
  })
_sym_db.RegisterMessage(RevokePermissionOutput)

CreateCodeTemplateInput = _reflection.GeneratedProtocolMessageType('CreateCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATECODETEMPLATEINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateCodeTemplateInput)
  })
_sym_db.RegisterMessage(CreateCodeTemplateInput)

CreateCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('CreateCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.CreateCodeTemplateOutput)
  })
_sym_db.RegisterMessage(CreateCodeTemplateOutput)

UpdateCodeTemplateInput = _reflection.GeneratedProtocolMessageType('UpdateCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECODETEMPLATEINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateCodeTemplateInput)
  })
_sym_db.RegisterMessage(UpdateCodeTemplateInput)

UpdateCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('UpdateCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.UpdateCodeTemplateOutput)
  })
_sym_db.RegisterMessage(UpdateCodeTemplateOutput)

DeleteCodeTemplateInput = _reflection.GeneratedProtocolMessageType('DeleteCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETECODETEMPLATEINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteCodeTemplateInput)
  })
_sym_db.RegisterMessage(DeleteCodeTemplateInput)

DeleteCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('DeleteCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DeleteCodeTemplateOutput)
  })
_sym_db.RegisterMessage(DeleteCodeTemplateOutput)

ListCodeTemplatesInput = _reflection.GeneratedProtocolMessageType('ListCodeTemplatesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTCODETEMPLATESINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListCodeTemplatesInput)
  })
_sym_db.RegisterMessage(ListCodeTemplatesInput)

ListCodeTemplatesOutput = _reflection.GeneratedProtocolMessageType('ListCodeTemplatesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTCODETEMPLATESOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ListCodeTemplatesOutput)
  })
_sym_db.RegisterMessage(ListCodeTemplatesOutput)

DescribeCodeTemplateInput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEINPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeCodeTemplateInput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateInput)

DescribeCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.atlas.atlas_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.DescribeCodeTemplateOutput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateOutput)


DESCRIPTOR._options = None

_ATLAS = _descriptor.ServiceDescriptor(
  name='Atlas',
  full_name='eolymp.atlas.Atlas',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3767,
  serialized_end=9579,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateProblem',
    full_name='eolymp.atlas.Atlas.CreateProblem',
    index=0,
    containing_service=None,
    input_type=_CREATEPROBLEMINPUT,
    output_type=_CREATEPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\033\"\020/atlas/problems/:\007problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProblem',
    full_name='eolymp.atlas.Atlas.DeleteProblem',
    index=1,
    containing_service=None,
    input_type=_DELETEPROBLEMINPUT,
    output_type=_DELETEPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036*\034/atlas/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListProblems',
    full_name='eolymp.atlas.Atlas.ListProblems',
    index=2,
    containing_service=None,
    input_type=_LISTPROBLEMSINPUT,
    output_type=_LISTPROBLEMSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\022\022\020/atlas/problems/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeProblem',
    full_name='eolymp.atlas.Atlas.DescribeProblem',
    index=3,
    containing_service=None,
    input_type=_DESCRIBEPROBLEMINPUT,
    output_type=_DESCRIBEPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\'\022\034/atlas/problems/{problem_id}b\007problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListExamples',
    full_name='eolymp.atlas.Atlas.ListExamples',
    index=4,
    containing_service=None,
    input_type=_LISTEXAMPLESINPUT,
    output_type=_LISTEXAMPLESOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002(\022&/atlas/problems/{problem_id}/examples/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVerifier',
    full_name='eolymp.atlas.Atlas.UpdateVerifier',
    index=5,
    containing_service=None,
    input_type=_UPDATEVERIFIERINPUT,
    output_type=_UPDATEVERIFIEROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0021\032%/atlas/problems/{problem_id}/verifier:\010verifier',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeVerifier',
    full_name='eolymp.atlas.Atlas.DescribeVerifier',
    index=6,
    containing_service=None,
    input_type=_DESCRIBEVERIFIERINPUT,
    output_type=_DESCRIBEVERIFIEROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0021\022%/atlas/problems/{problem_id}/verifierb\010verifier',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateInteractor',
    full_name='eolymp.atlas.Atlas.UpdateInteractor',
    index=7,
    containing_service=None,
    input_type=_UPDATEINTERACTORINPUT,
    output_type=_UPDATEINTERACTOROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0025\032\'/atlas/problems/{problem_id}/interactor:\ninteractor',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeInteractor',
    full_name='eolymp.atlas.Atlas.DescribeInteractor',
    index=8,
    containing_service=None,
    input_type=_DESCRIBEINTERACTORINPUT,
    output_type=_DESCRIBEINTERACTOROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0025\022\'/atlas/problems/{problem_id}/interactorb\ninteractor',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStatement',
    full_name='eolymp.atlas.Atlas.CreateStatement',
    index=9,
    containing_service=None,
    input_type=_CREATESTATEMENTINPUT,
    output_type=_CREATESTATEMENTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0025\032(/atlas/problems/{problem_id}/statements/:\tstatement',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateStatement',
    full_name='eolymp.atlas.Atlas.UpdateStatement',
    index=10,
    containing_service=None,
    input_type=_UPDATESTATEMENTINPUT,
    output_type=_UPDATESTATEMENTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\032 /atlas/statements/{statement_id}:\tstatement',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteStatement',
    full_name='eolymp.atlas.Atlas.DeleteStatement',
    index=11,
    containing_service=None,
    input_type=_DELETESTATEMENTINPUT,
    output_type=_DELETESTATEMENTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\"* /atlas/statements/{statement_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListStatements',
    full_name='eolymp.atlas.Atlas.ListStatements',
    index=12,
    containing_service=None,
    input_type=_LISTSTATEMENTSINPUT,
    output_type=_LISTSTATEMENTSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002*\022(/atlas/problems/{problem_id}/statements/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeStatement',
    full_name='eolymp.atlas.Atlas.DescribeStatement',
    index=13,
    containing_service=None,
    input_type=_DESCRIBESTATEMENTINPUT,
    output_type=_DESCRIBESTATEMENTOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002-\022 /atlas/statements/{statement_id}b\tstatement',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTestset',
    full_name='eolymp.atlas.Atlas.CreateTestset',
    index=14,
    containing_service=None,
    input_type=_CREATETESTSETINPUT,
    output_type=_CREATETESTSETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0021\"&/atlas/problems/{problem_id}/testsets/:\007testset',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTestset',
    full_name='eolymp.atlas.Atlas.UpdateTestset',
    index=15,
    containing_service=None,
    input_type=_UPDATETESTSETINPUT,
    output_type=_UPDATETESTSETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\'\032\034/atlas/testsets/{testset_id}:\007testset',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTestset',
    full_name='eolymp.atlas.Atlas.DeleteTestset',
    index=16,
    containing_service=None,
    input_type=_DELETETESTSETINPUT,
    output_type=_DELETETESTSETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/atlas/testsets/{testset_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTestsets',
    full_name='eolymp.atlas.Atlas.ListTestsets',
    index=17,
    containing_service=None,
    input_type=_LISTTESTSETSINPUT,
    output_type=_LISTTESTSETSOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002(\022&/atlas/problems/{problem_id}/testsets/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeTestset',
    full_name='eolymp.atlas.Atlas.DescribeTestset',
    index=18,
    containing_service=None,
    input_type=_DESCRIBETESTSETINPUT,
    output_type=_DESCRIBETESTSETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\'\022\034/atlas/testsets/{testset_id}b\007testset',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTest',
    full_name='eolymp.atlas.Atlas.CreateTest',
    index=19,
    containing_service=None,
    input_type=_CREATETESTINPUT,
    output_type=_CREATETESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002*\"\"/atlas/testsets/{testset_id}/tests:\004test',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTest',
    full_name='eolymp.atlas.Atlas.UpdateTest',
    index=20,
    containing_service=None,
    input_type=_UPDATETESTINPUT,
    output_type=_UPDATETESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\026/atlas/tests/{test_id}:\004test',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTest',
    full_name='eolymp.atlas.Atlas.DeleteTest',
    index=21,
    containing_service=None,
    input_type=_DELETETESTINPUT,
    output_type=_DELETETESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\030*\026/atlas/tests/{test_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTests',
    full_name='eolymp.atlas.Atlas.ListTests',
    index=22,
    containing_service=None,
    input_type=_LISTTESTSINPUT,
    output_type=_LISTTESTSOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$\022\"/atlas/testsets/{testset_id}/tests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeTest',
    full_name='eolymp.atlas.Atlas.DescribeTest',
    index=23,
    containing_service=None,
    input_type=_DESCRIBETESTINPUT,
    output_type=_DESCRIBETESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036\022\026/atlas/tests/{test_id}b\004test',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GrantPermission',
    full_name='eolymp.atlas.Atlas.GrantPermission',
    index=24,
    containing_service=None,
    input_type=_GRANTPERMISSIONINPUT,
    output_type=_GRANTPERMISSIONOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026atlas:permission:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0026\"(/atlas/problems/{problem_id}/permissions:\npermission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokePermission',
    full_name='eolymp.atlas.Atlas.RevokePermission',
    index=25,
    containing_service=None,
    input_type=_REVOKEPERMISSIONINPUT,
    output_type=_REVOKEPERMISSIONOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026atlas:permission:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0024*2/atlas/problems/{problem_id}/permissions/{user_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPermissions',
    full_name='eolymp.atlas.Atlas.ListPermissions',
    index=26,
    containing_service=None,
    input_type=_LISTPERMISSIONSINPUT,
    output_type=_LISTPERMISSIONSOUTPUT,
    serialized_options=b'\202\343\n\031\212\343\n\025atlas:permission:read\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002*\022(/atlas/problems/{problem_id}/permissions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCodeTemplate',
    full_name='eolymp.atlas.Atlas.CreateCodeTemplate',
    index=27,
    containing_service=None,
    input_type=_CREATECODETEMPLATEINPUT,
    output_type=_CREATECODETEMPLATEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0022\"&/atlas/problems/{problem_id}/templates:\010template',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCodeTemplate',
    full_name='eolymp.atlas.Atlas.UpdateCodeTemplate',
    index=28,
    containing_service=None,
    input_type=_UPDATECODETEMPLATEINPUT,
    output_type=_UPDATECODETEMPLATEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002*\"\036/atlas/templates/{template_id}:\010template',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCodeTemplate',
    full_name='eolymp.atlas.Atlas.DeleteCodeTemplate',
    index=29,
    containing_service=None,
    input_type=_DELETECODETEMPLATEINPUT,
    output_type=_DELETECODETEMPLATEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002 *\036/atlas/templates/{template_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCodeTemplates',
    full_name='eolymp.atlas.Atlas.ListCodeTemplates',
    index=30,
    containing_service=None,
    input_type=_LISTCODETEMPLATESINPUT,
    output_type=_LISTCODETEMPLATESOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002)\022\'/atlas/problems/{problems_id}/templates',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCodeTemplate',
    full_name='eolymp.atlas.Atlas.DescribeCodeTemplate',
    index=31,
    containing_service=None,
    input_type=_DESCRIBECODETEMPLATEINPUT,
    output_type=_DESCRIBECODETEMPLATEOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002*\022\036/atlas/templates/{template_id}b\010template',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ATLAS)

DESCRIPTOR.services_by_name['Atlas'] = _ATLAS

# @@protoc_insertion_point(module_scope)
